==> qucs-s-debug-24.4.0-1-x86_64.pkg.tar.zst: usr/src/debug/qucs-s/qucs-s-24.4.0/builddir/qucsator_rf/src/parse_zvr.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_ZVR_PARSE_ZVR_HPP_INCLUDED
# define YY_ZVR_PARSE_ZVR_HPP_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int zvr_debug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    ZVR = 258,                     /* ZVR  */
    Version = 259,                 /* Version  */
    Identifier = 260,              /* Identifier  */
    Real = 261,                    /* Real  */
    Unit = 262,                    /* Unit  */
    DataFMT = 263,                 /* DataFMT  */
    DataTYP = 264,                 /* DataTYP  */
    DataIDN = 265,                 /* DataIDN  */
    InvalidCharacter = 266         /* InvalidCharacter  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 62 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"

  char * ident;
  double f;
  struct zvr_data_t * data;
  struct zvr_header_t * head;
  struct zvr_vector_t * vec;
  struct zvr_line_t * line;

#line 84 "parse_zvr.hpp"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE zvr_lval;


int zvr_parse (void);


#endif /* !YY_ZVR_PARSE_ZVR_HPP_INCLUDED  */

==> qucs-s-debug-25.1.1-1-x86_64.pkg.tar.zst: usr/src/debug/qucs-s/qucs-s-25.1.1/builddir/qucsator_rf/src/parse_zvr.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_ZVR_PARSE_ZVR_HPP_INCLUDED
# define YY_ZVR_PARSE_ZVR_HPP_INCLUDED
/* Debug traces.  */
#ifndef ZVR_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define ZVR_DEBUG 1
#  else
#   define ZVR_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define ZVR_DEBUG 0
# endif /* ! defined YYDEBUG */
#endif  /* ! defined ZVR_DEBUG */
#if ZVR_DEBUG
extern int zvr_debug;
#endif

/* Token kinds.  */
#ifndef ZVR_TOKENTYPE
# define ZVR_TOKENTYPE
  enum zvr_tokentype
  {
    ZVR_EMPTY = -2,
    ZVR_EOF = 0,                   /* "end of file"  */
    ZVR_error = 256,               /* error  */
    ZVR_UNDEF = 257,               /* "invalid token"  */
    ZVR = 258,                     /* ZVR  */
    Version = 259,                 /* Version  */
    Identifier = 260,              /* Identifier  */
    Real = 261,                    /* Real  */
    Unit = 262,                    /* Unit  */
    DataFMT = 263,                 /* DataFMT  */
    DataTYP = 264,                 /* DataTYP  */
    DataIDN = 265,                 /* DataIDN  */
    InvalidCharacter = 266         /* InvalidCharacter  */
  };
  typedef enum zvr_tokentype zvr_token_kind_t;
#endif

/* Value type.  */
#if ! defined ZVR_STYPE && ! defined ZVR_STYPE_IS_DECLARED
union ZVR_STYPE
{
#line 62 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"

  char * ident;
  double f;
  struct zvr_data_t * data;
  struct zvr_header_t * head;
  struct zvr_vector_t * vec;
  struct zvr_line_t * line;

#line 92 "parse_zvr.hpp"

};
typedef union ZVR_STYPE ZVR_STYPE;
# define ZVR_STYPE_IS_TRIVIAL 1
# define ZVR_STYPE_IS_DECLARED 1
#endif


extern ZVR_STYPE zvr_lval;


int zvr_parse (void);


#endif /* !YY_ZVR_PARSE_ZVR_HPP_INCLUDED  */
